## Loading packages
##*********************
library(vegan)
library(ape)
library(picante)
library (ade4)

###################################################################################
## Loading data
####################################################################################

my_data <- read.csv("frog_data.csv", header = T, row.names = 1)
head(my_data)

environmental <- read.csv("worldclim_2_5.csv", header = T, row.names = 1,
                       sep = ";")
head(environmental)

tree <- read.tree("tree_pyron_112_species")

coord <- read.csv("coordinates.csv", header = T, row.names = 1, sep = ",")
coord


# Ckecking species names
setdiff(colnames(my_data), tree$tip.label) 

# Putting the names of the species in the same sequence 
my_data <- my_data[,match(tree$tip.label,colnames(my_data))]
head(my_data)


################################################################################
## PCA CONTEMPORARY CLIMATE
################################################################################

PCA_CON <- environmental[,c(1:8)]

PCA.CON <- prcomp (PCA_CON, 
                    scale = TRUE)

summary(PCA.CON)

PC1.CON <- c(PCA.CON$x[,1]) # bio 15 + bio 17 
PC2.CON <- c(PCA.CON$x[,2]) # Bio 16 & Bio 12

################################################################################
## PCA LGM 
################################################################################

PCA_lgm <- environmental[,c(33:40)]

PCA_LGM <- prcomp (PCA_lgm, 
                     scale = TRUE)

summary(PCA_LGM)

PC1_LGM <- c(PCA_LGM$x[,1]) # bio17 & bio15
PC2_LGM <- c(PCA_LGM$x[,2]) # bio1 + bio 11 & bio 4


################################################################################
## PCA ALTITUDE
################################################################################

PCA_alt <- environmental[,c(41:43)]

PCA.ALT <- prcomp (PCA_alt, 
                    scale = TRUE)

summary(PCA.ALT)

PC1.ALT <- c(PCA.ALT$x[,1])
PC2.ALT <- c(PCA.ALT$x[,2])

##################### PHYLOGENETIC COMMUNITY STRUCTURE ########################
###############################################################################

## NRI ######################################################################
#****************************************************************************
NRI_total <- ses.mpd(my_data, cophenetic(tree), null.model = "independentswap",
                      abundance.weighted = FALSE, runs = 999)

## NTI #########################################################################
#******************************************************************************
NTI_total <-ses.mntd(my_data, cophenetic(tree), null.model = "independentswap",
                      runs=999)


##########  SEPARETED BY REGION  #################################################################
##************************************************************************************************

# COASTAL REGION 
#**************************************************************************************************
coastal_data <- my_data[c(8:14),]
coastal_data <- as.data.frame(coastal_data)
coastal_data[8,] <- as.numeric(colSums(coastal_data))
coastal_data <- coastal_data[,which(coastal_data[8,] > 0)]
coastal_data <- coastal_data[-8,] 
str(coastal_data) # 89 species

coastal_tree <- drop.tip(tree, setdiff(tree$tip.label, 
                                                     colnames(coastal_data))) # 89 espcies

## COASTAL NRI & NTI

NRI_coastal <- ses.mpd(coastal_data, cophenetic(coastal_tree), null.model = "independentswap", 
                          abundance.weighted = FALSE, runs = 999)

NTI_coastal <-ses.mntd(coastal_data, cophenetic(coastal_tree), null.model = "independentswap",
                       runs=999)

# INLAND REGION
#*************************************************************************************************
inland_data <- my_data[c(1:7),]
inland_data <- as.data.frame(inland_data)
inland_data[8,] <- colSums(inland_data)
inland_data <- inland_data[,which(inland_data[8,] > 0)]
inland_data <- inland_data[-8,] 
str(inland_data) # 37 species


inland_tree <- drop.tip(tree, setdiff(tree$tip.label, 
                                                     colnames(inland_data))) # 37 espcies

## INLAND NRI & NTI

NRI_inland <- ses.mpd(inland_data, cophenetic(inland_tree), null.model = "independentswap", 
                        abundance.weighted = FALSE, runs = 999)

NTI_inland <-ses.mntd(inland_data, cophenetic(inland_tree), 
                        null.model = "independentswap",runs=99)


##################### FUNCTIONAL COMMUNITY STRUCTURE ########################
###############################################################################

# Loanding traits of reproductive modes regions together
atribute <- read.csv("reproductive_modes_total.csv", header = T, row.names= 1, sep = ";")
head(atribute)


## Calculating dissimilarity 
atribute_dist <- as.matrix(dist.binary(atribute, method = 2, upper = T, diag = T))


## NRI & NTI FUNCTIONAL

NRI_funcional <- ses.mpd(my_data, atribute_dist, abundance.weighted = F, 
                          null.model = "independentswap", runs = 999)

NTI_funcional <- ses.mntd(my_data, atribute_dist, abundance.weighted = F, 
                           null.model = "independentswap", runs = 999)


## COASTAL REGION
##******************************************************************************************

coastal_atributes <- read.csv("reproductive_modes_coastal.csv", row.names = 1, header = T)
head(coastal_atributes)

# Matching
coastal_data <- coastal_data[,match(rownames(coastal_atributes), colnames(coastal_data))]
head(coastal_data)


## Dissimilarity
dist_coastal <- as.matrix(dist.binary(coastal_atributes, method = 2, upper = T, diag = T))

NRI_funcional_coastal <- ses.mpd(coastal_data, dist_coastal, abundance.weighted = F, 
                                null.model = "independentswap", runs = 999)
NTI_funcional_coastal <- ses.mntd(coastal_data, dist_coastal, abundance.weighted = F, 
                                 null.model = "independentswap", runs = 999)

## INLAND REGION
##******************************************************************************************

inland_atributes <- read.csv("reproductive_modes_inland.csv", row.names = 1, header = T)
head(inland_atributes)

# Matching
inland_data <- inland_data[,match(rownames(inland_atributes), colnames(inland_data))]
head(inland_data)


## Dissimilarity
dist_inland <- as.matrix(dist.binary(inland_atributes, method = 2, upper = T, diag = T))

NRI_funcional_inland <- ses.mpd(inland_data, dist_inland, abundance.weighted = F, 
                                 null.model = "independentswap", runs = 999)
NTI_funcional_inland <- ses.mntd(inland_data, dist_inland, abundance.weighted = F, 
                                  null.model = "independentswap", runs = 999)

