## Loadinga packages
#************************************************************************************
library(nlme)
library(bbmle)

## Loading data
##*************************************************************************************
data <- read.csv("results_phylogenetic_metrics_compiled.csv", header = T, row.names = 1, 
                 sep = ",")
head(data)

## SR REGIONS TOGETHER
##*************************************************************************************
M1_SR <- gls (Richness~ PC1.ATUAL, data = data, 
              correlation = corExp (form = ~ Longitude + Latitude))

M2_SR <- gls (Richness~ PC1.LGM, data = data, 
              correlation = corExp (form = ~ Longitude + Latitude))

M3_SR <- gls (Richness~ PC1.ALT, data = data, 
              correlation = corExp (form = ~ Longitude + Latitude))

M4_SR <- gls (Richness~ Region, data = data, 
              correlation = corExp (form = ~ Longitude + Latitude))

M5_SR <- gls (Richness~ 1, data = data, 
              correlation = corExp (form = ~ Longitude + Latitude))

M6_SR <- gls (Richness~ PC1.ATUAL + PC1.ALT, data = data, 
              correlation = corExp (form = ~ Longitude + Latitude))

M7_SR <- gls (Richness~ PC1.LGM + PC1.ALT, data = data, 
              correlation = corExp (form = ~ Longitude + Latitude))

## Model Selection
##**********************************
AICc.SR <- ICtab(M1_SR, M2_SR, M3_SR, M4_SR, M5_SR, M6_SR, M7_SR, 
                 type = c("AICc"), base = TRUE,  weights = TRUE, delta = TRUE, sort = TRUE, 
                 logLik = T, nobs= 14)
AICc.SR 


## SR INLAND SITES
##****************************************************************************************
M1_SR_inland <- gls (Richness~ PC1.ATUAL, data = data[1:7,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M2_SR_inland <- gls (Richness~ PC1.LGM, data = data[1:7,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M3_SR_inland <- gls (Richness~ PC1.ALT, data = data[1:7,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M4_SR_inland <- gls (Richness~ 1, data = data[1:7,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M5_SR_inland <- gls (Richness~ PC1.ATUAL + PC1.LGM, data = data[1:7,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M6_SR_inland <- gls (Richness~ PC1.ATUAL + PC1.ALT, data = data[1:7,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M7_SR_inland <- gls (Richness~ PC1.LGM + PC1.ALT, data = data[1:7,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

## Model selection
##**********************************
AICc.SR_inland <- ICtab(M1_SR_inland, M2_SR_inland, M3_SR_inland, M4_SR_inland,
                        M5_SR_inland, M6_SR_inland, M7_SR_inland, 
                        type = c("AICc"), base = TRUE, weights = TRUE, delta = TRUE, 
                        sort = TRUE, logLik = T,
                        nobs= 7)
AICc.SR_inland 



## SR COASTAL SITES
##****************************************************************************************
M1_SR_coastal <- gls (Richness~ PC1.ATUAL, data = data[8:14,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M2_SR_coastal <- gls (Richness~ PC1.LGM, data = data[8:14,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M3_SR_coastal <- gls (Richness~ PC1.ALT, data = data[8:14,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M4_SR_coastal <- gls (Richness~ 1, data = data[8:14,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M5_SR_coastal <- gls (Richness~ PC1.ATUAL + PC1.LGM, data = data[8:14,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M6_SR_coastal <- gls (Richness~ PC1.ATUAL + PC1.ALT, data = data[8:14,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M7_SR_coastal <- gls (Richness~  PC1.LGM + PC1.ALT, data = data[8:14,], 
                      correlation = corExp (form = ~ Longitude + Latitude))


## Model selection
##**********************************
AICc.SR_coastal <- ICtab(M1_SR_coastal, M2_SR_coastal, M3_SR_coastal, M4_SR_coastal, 
                         M5_SR_coastal, M6_SR_coastal, M7_SR_coastal,  
                         type = c("AICc"), base = TRUE, weights = TRUE, delta = TRUE, 
                         sort = TRUE, logLik = T,
                         nobs= 7)
AICc.SR_coastal 


