## Loadinga packages
#************************************************************************************
library(nlme)
library(bbmle)

## Loading data
##*************************************************************************************
data <- read.csv("results_phylogenetic_metrics_compiled.csv", header = T, row.names = 1, 
                  sep = ",")
head(data)

######################################## NRI ###########################################
########################################################################################

## NRI REGIONS TOGETHER
##*************************************************************************************
M1_NRI <- gls (NRI_ses ~ PC1.ATUAL, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M2_NRI <- gls (NRI_ses ~ PC1.LGM, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M3_NRI <- gls (NRI_ses ~ PC1.ALT, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M4_NRI <- gls (NRI_ses ~ Region, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M5_NRI <- gls (NRI_ses ~ 1, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M6_NRI <- gls (NRI_ses ~ PC1.ATUAL + PC1.ALT, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M7_NRI <- gls (NRI_ses ~ PC1.LGM + PC1.ALT, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

## Model Selection
##**********************************
AICc.NRI <- ICtab(M1_NRI, M2_NRI, M3_NRI, M4_NRI, M5_NRI, M6_NRI, M7_NRI, 
                  type = c("AICc"), base = TRUE,  weights = TRUE, delta = TRUE, sort = TRUE, 
                  logLik = T, nobs= 14)
AICc.NRI 


## NRI INLAND SITES
##****************************************************************************************
M1_NRI_inland <- gls (NRI_pool_ses ~ PC1.ATUAL, data = data[1:7,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M2_NRI_inland <- gls (NRI_pool_ses ~ PC1.LGM, data = data[1:7,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M3_NRI_inland <- gls (NRI_pool_ses ~ PC1.ALT, data = data[1:7,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M4_NRI_inland <- gls (NRI_pool_ses ~ 1, data = data[1:7,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M5_NRI_inland <- gls (NRI_pool_ses ~ PC1.ATUAL + PC1.LGM, data = data[1:7,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M6_NRI_inland <- gls (NRI_pool_ses ~ PC1.ATUAL + PC1.ALT, data = data[1:7,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M7_NRI_inland <- gls (NRI_pool_ses ~ PC1.LGM + PC1.ALT, data = data[1:7,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

## Model selection
##**********************************
AICc.NRI_inland <- ICtab(M1_NRI_inland, M2_NRI_inland, M3_NRI_inland, M4_NRI_inland,
                         M5_NRI_inland, M6_NRI_inland, M7_NRI_inland, 
                           type = c("AICc"), base = TRUE, weights = TRUE, delta = TRUE, 
                           sort = TRUE, logLik = T,
                           nobs= 7)
AICc.NRI_inland 



## NRI COASTAL SITES
##****************************************************************************************
M1_NRI_coastal <- gls (NRI_pool_ses ~ PC1.ATUAL, data = data[8:14,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M2_NRI_coastal <- gls (NRI_pool_ses ~ PC1.LGM, data = data[8:14,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M3_NRI_coastal <- gls (NRI_pool_ses ~ PC1.ALT, data = data[8:14,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M4_NRI_coastal <- gls (NRI_pool_ses ~ 1, data = data[8:14,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M5_NRI_coastal <- gls (NRI_pool_ses ~ PC1.ATUAL + PC1.LGM, data = data[8:14,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M6_NRI_coastal <- gls (NRI_pool_ses ~ PC1.ATUAL + PC1.ALT, data = data[8:14,], 
                     correlation = corExp (form = ~ Longitude + Latitude))

M7_NRI_coastal <- gls (NRI_pool_ses ~  PC1.LGM + PC1.ALT, data = data[8:14,], 
                     correlation = corExp (form = ~ Longitude + Latitude))


## Model selection
##**********************************
AICc.NRI_coastal <- ICtab(M1_NRI_coastal, M2_NRI_coastal, M3_NRI_coastal, M4_NRI_coastal, 
                          M5_NRI_coastal, M6_NRI_coastal, M7_NRI_coastal,  
                        type = c("AICc"), base = TRUE, weights = TRUE, delta = TRUE, 
                        sort = TRUE, logLik = T,
                        nobs= 7)
AICc.NRI_coastal 

######################################## NTI ###########################################
########################################################################################

## NTI REGIONS TOGETHER
##**************************************************************************************
M1_NTI <- gls (NTI_ses ~ PC1.ATUAL, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M2_NTI <- gls (NTI_ses ~ PC1.LGM, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M3_NTI <- gls (NTI_ses ~ PC1.ALT, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M4_NTI <- gls (NTI_ses ~ Region, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M5_NTI <- gls (NTI_ses ~ 1, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M6_NTI <- gls (NTI_ses ~ PC1.ATUAL + PC1.ALT, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))

M7_NTI <- gls (NTI_ses ~ PC1.LGM + PC1.ALT, data = data, 
               correlation = corExp (form = ~ Longitude + Latitude))


## Model selection
##**********************************
AICc.NTI <- ICtab(M1_NTI, M2_NTI, M3_NTI, M4_NTI, M5_NTI, M6_NTI, M7_NTI, 
                  type = c("AICc"), base = TRUE, weights = TRUE, delta = TRUE, sort = TRUE,
                  logLik = T, nobs= 14)
AICc.NTI 


## NTI Inland 
##******************************************************************************************
M1_NTI_inland <- gls (NTI_pool_ses ~ PC1.ATUAL, data = data[1:7,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M2_NTI_inland <- gls (NTI_pool_ses ~ PC1.LGM, data = data[1:7,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M3_NTI_inland <- gls (NTI_pool_ses ~ PC1.ALT, data = data[1:7,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M4_NTI_inland <- gls (NTI_pool_ses ~ 1, data = data[1:7,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M5_NTI_inland <- gls (NTI_pool_ses ~ PC1.ATUAL + PC1.LGM, data = data[1:7,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M6_NTI_inland <- gls (NTI_pool_ses ~ PC1.ATUAL + PC1.ALT, data = data[1:7,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

M7_NTI_inland <- gls (NTI_pool_ses ~ PC1.LGM + PC1.ALT, data = data[1:7,], 
                      correlation = corExp (form = ~ Longitude + Latitude))

## Selecionando o melhor modelo
##**********************************
AICc.NTI_inland <- ICtab(M1_NTI_inland, M2_NTI_inland, M3_NTI_inland, M4_NTI_inland, 
                         M5_NTI_inland, M6_NTI_inland, M7_NTI_inland,  
                         type = c("AICc"), base = TRUE, weights = TRUE, delta = TRUE,
                         sort = TRUE, logLik = T, nobs= 7)
AICc.NTI_inland 


## NTI Coastal 
##**************************************************************************************
M1_NTI_coastal <- gls (NTI_pool_ses ~ PC1.ATUAL, data = data[8:14,], 
                       correlation = corExp (form = ~ Longitude + Latitude))

M2_NTI_coastal  <- gls (NTI_pool_ses ~ PC1.LGM, data = data[8:14,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M3_NTI_coastal  <- gls (NTI_pool_ses ~ PC1.ALT, data = data[8:14,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M4_NTI_coastal  <- gls (NTI_pool_ses ~ 1, data = data[8:14,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M5_NTI_coastal  <- gls (NTI_pool_ses ~ PC1.ATUAL + PC1.LGM, data = data[8:14,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M6_NTI_coastal  <- gls (NTI_pool_ses ~ PC1.ATUAL + PC1.ALT, data = data[8:14,], 
                        correlation = corExp (form = ~ Longitude + Latitude))

M7_NTI_coastal  <- gls (NTI_pool_ses ~ PC1.LGM + PC1.ALT, data = data[8:14,], 
                        correlation = corExp (form = ~ Longitude + Latitude))


## Model selection
##**********************************
AICc.NTI_coastal <- ICtab(M1_NTI_coastal, M2_NTI_coastal, M3_NTI_coastal, M4_NTI_coastal,  
                          M5_NTI_coastal, M6_NTI_coastal, M7_NTI_coastal,
                          type = c("AICc"), base = TRUE, weights = TRUE, delta = TRUE, 
                          sort = TRUE, logLik = T, nobs= 7)
AICc.NTI_coastal 


