library(phytools)

## Loading the tree with frog species sampled in our study
tree <- read.tree("tree_pyron_112_species")

## Loading data of presence and absence of frog species in the local communities
my_data <- read.csv("frog_data.csv", header = T, row.names = 1)
head(my_data)


# Cheking species names
setdiff(colnames(my_data), tree$tip.label) 
setdiff(tree$tip.label, colnames(my_data)) 

# Separating data by coastal and inland regions
## COastal region
coastal_data <- my_data[c(8:14),]
coastal_data <- as.data.frame(coastal_data)
coastal_data[8,] <- as.numeric(colSums(coastal_data))
coastal_data <- coastal_data[,which(coastal_data[8,] > 0)]
coastal_data <- coastal_data[-8,] # 89 especies

coastal_tree <- drop.tip(tree, setdiff(tree$tip.label, colnames(coastal_data))) # 89 espcies

# Inland region
inland_region <- my_data[c(1:7),]
inland_region <- as.data.frame(inland_region)
inland_region[8,] <- colSums(inland_region)
inland_region <- inland_region[,which(inland_region[8,] > 0)]
inland_region <- inland_region[-8,] # 37 espcies

inland_tree <- drop.tip(tree, setdiff(tree$tip.label, colnames(inland_region))) # 37 espcies


## Making a list with all trees
trees <- list(tree, coastal_tree, inland_tree)
class(trees) <- "multiPhylo"
trees

## We altered the colors of mll.plot function

altered_mll.plot <- function (phy, ..., dcol = TRUE, dlty = FALSE, legend = TRUE, 
                   xlab = "Time", ylab = "N", log = "", backward = TRUE, tol = 1e-06) 
{
  if (inherits(phy, "phylo")) {
    TREES <- list(ltt.plot.coords(phy, backward, tol))
    names(TREES) <- deparse(substitute(phy))
  }
  else {
    TREES <- lapply(phy, ltt.plot.coords, backward = backward, 
                    tol = tol)
    names(TREES) <- names(phy)
    if (is.null(names(TREES))) 
      names(TREES) <- paste(deparse(substitute(phy)), "-", 
                            1:length(TREES))
  }
  dts <- list(...)
  n <- length(dts)
  if (n) {
    mc <- as.character(match.call())[-(1:2)]
    nms <- mc[1:n]
    for (i in 1:n) {
      if (inherits(dts[[i]], "phylo")) {
        a <- list(ltt.plot.coords(dts[[i]], backward, 
                                  tol))
        names(a) <- nms[i]
      }
      else {
        a <- lapply(dts[[i]], ltt.plot.coords, backward = backward, 
                    tol = tol)
        names(a) <- names(dts[[i]])
        if (is.null(names(a))) 
          names(a) <- paste(deparse(substitute(phy)), 
                            "-", seq_along(a))
      }
      TREES <- c(TREES, a)
    }
  }
  n <- length(TREES)
  range.each.tree <- sapply(TREES, function(x) range(x[, 1]))
  xl <- range(range.each.tree)
  yl <- c(1, max(sapply(TREES, function(x) max(x[, 2]))))
  if (!backward) {
    for (i in seq_along(TREES)) {
      tmp <- TREES[[i]]
      tmp[, 1] <- tmp[, 1] + xl[2] - range.each.tree[2, 
                                                     i]
      TREES[[i]] <- tmp
    }
  }
  plot.default(NA, type = "n", xlim = xl, ylim = yl, xaxs = "r", 
               yaxs = "r", xlab = xlab, ylab = ylab, log = log)
  lty <- if (!dlty) 
    rep(1, n)
  else 1:n
  col <- if (!dcol) 
    rep(1, n)
  else c("black", "green", "deepskyblue1")
  for (i in 1:n) lines(TREES[[i]], col = col[i], lty = lty[i], lwd = 8, 
                       type = "S")
  if (legend) 
    legend(xl[1], yl[2], legend = names(TREES), lty = lty, 
           col = col[i], bty = "n")
}

altered_mll.plot(trees)


########################################################################
## FIGURE WILL ALL LTTS
########################################################################
b <-phytools:::qb(tree)
trees <- pbtree(b = b , n = Ntip(tree),t = max(nodeHeights(tree)),
              nsim = 100, method = "direct", quiet = TRUE)
obj <- ltt(trees, plot=FALSE)

bd.model <- fit.bd(tree, rho = 0.1)
yule.model <- fit.yule(tree, rho = 0.1)
AIC(yule.model,bd.model)

c <-phytools:::qb(coastal_tree)

i <-phytools:::qb(inland_tree)

plot(obj, col="gray90", main="LTTs")
## now let's overlay our original tree
ltt(tree, add = TRUE, lwd = 4, col="black")
ltt(coastal_tree, add = TRUE, lwd = 4, col="green")
ltt(inland_tree, add = TRUE, lwd = 4, col="blue")

