## Loading packages
##*********************
library(vegan)
library(ape)
library(betapart)
library(picante)
library(devtools)
# install_github("Russel88/MicEco")
library(MicEco)
library(foreach)
library (ade4)
library (FD)

## Loading and organizing data
#***********************************************************************************

my_data <- read.csv("frog_data.csv", header = T, row.names = 1)
head(my_data)

tree <- read.tree("tree_pyron_112_species")

atribute <- read.csv("reproductive_modes_total.csv", header = T, row.names= 1, sep = ";")
head(atribute)


## Checking names of species between tree and composition
setdiff(colnames(my_data), tree$tip.label) 

## Checking names of species between atributes and composition 
setdiff(colnames(my_data), rownames(atribute))

## Putting names of species in the same sequence
my_data <- my_data[,match(tree$tip.label,colnames(my_data))]
head(my_data)

## Putting names of species in the same sequence
atribute <- atribute[match(colnames(my_data), rownames(atribute)),]
head(atribute)


##########  SEPARETING DATA BY REGION  ######################################################
##*******************************************************************************************

# COASTAL REGION 
#********************************************************************************************
coastal_data <- my_data[c(8:14),]
coastal_data <- as.data.frame(coastal_data)
coastal_data[8,] <- as.numeric(colSums(coastal_data))
coastal_data <- coastal_data[,which(coastal_data[8,] > 0)]
coastal_data <- coastal_data[-8,] 
str(coastal_data) # 89 species

coastal_tree <- drop.tip(tree, setdiff(tree$tip.label, 
                                       colnames(coastal_data))) # 89 espcies

# INLAND REGION
#*********************************************************************************************
inland_data <- my_data[c(1:7),]
inland_data <- as.data.frame(inland_data)
inland_data[8,] <- colSums(inland_data)
inland_data <- inland_data[,which(inland_data[8,] > 0)]
inland_data <- inland_data[-8,] 
str(inland_data) # 37 species


inland_tree <- drop.tip(tree, setdiff(tree$tip.label, 
                                      colnames(inland_data))) # 37 espcies



################################ PHYLOGENTIC BETA #############################################
###############################################################################################

## Phylogenetic beta- sites from both regions
##**********************************************************************************************

comdist.result <- comdist(my_data, cophenetic(tree))
comdistnt.result <- comdistnt(my_data, cophenetic(tree))


# Standardized Effect Size (SES)
ses_comdist <- ses.comdist(my_data, cophenetic(tree),
                           null.model = "independentswap", runs = 999)
ses_comdistnt <- ses.comdistnt(my_data, cophenetic(tree),
                               null.model = "independentswap", runs = 999)


## Phylogenetic beta - only Coastal sites
##*****************************************************************************
comdist.result_coastal <- comdist(coastal_data, cophenetic(coastal_tree))
comdistnt.result_coastal <- comdistnt(coastal_data, cophenetic(coastal_tree))

# SES
ses_comdist_coastal <- ses.comdist(coastal_data,  cophenetic(coastal_tree),
                           null.model = "independentswap", runs = 999)
ses_comdistnt_coastal <- ses.comdistnt(coastal_data,  cophenetic(coastal_tree),
                               null.model = "independentswap", runs = 999)

## Phylogenetic beta - only Inland sites
##*****************************************************************************
comdist.result_inland <- comdist(inland_data, cophenetic(inland_tree))
comdistnt.result_inland <- comdistnt(inland_data, cophenetic(inland_tree))

# SES
ses_comdist_inland <- ses.comdist(inland_data,  cophenetic(inland_tree),
                                   null.model = "independentswap", runs = 999)
ses_comdistnt_inland <- ses.comdistnt(inland_data,  cophenetic(inland_tree),
                                       null.model = "independentswap", runs = 999)


################################ FUNCTIONAL BETA #############################################
###############################################################################################

## Functional beta- sites from both regions
##**********************************************************************************************

## Dissimilarity
atribute_dist <- as.matrix(dist.binary(atribute, method = 2, upper = T, diag = T))

comdist.result_Func <- comdist(my_data, atribute_dist)
comdistnt.result_Func <- comdistnt(my_data, atribute_dist)

# SES
ses_comdist_Func <- ses.comdist(my_data, atribute_dist,
                           null.model = "independentswap", runs = 999)
ses_comdistnt_Func <- ses.comdistnt(my_data, atribute_dist,
                               null.model = "independentswap", runs = 999)


## Functional beta - only Coastal sites
##*****************************************************************************

atribute_coastal <- read.csv("reproductive_modes_coastal.csv", header = TRUE, row.names = 1,
                     sep = ",")
head(atribute_coastal)

## Putting names of species in the same sequence
atribute_coastal <- atribute_coastal[match(colnames(coastal_data), rownames(atribute_coastal)),]
head(atribute_coastal)

## Dissimilarity
atribute_dist_coastal <- as.matrix(dist.binary(atribute_coastal, method = 2, upper = T, diag = T))

comdist.result_coastal_Func <- comdist(coastal_data, atribute_dist_coastal)
comdistnt.result_coastal_Func <- comdistnt(coastal_data, atribute_dist_coastal)

## SES
ses_comdist_coastal_Func <- ses.comdist(coastal_data, atribute_dist_coastal,
                                    null.model = "independentswap", runs = 999)
ses_comdistnt_coastal_Func <- ses.comdistnt(coastal_data, atribute_dist_coastal,
                                        null.model = "independentswap", runs = 999)


## Functional beta - only Inland sites
##*****************************************************************************

atribute_inland <- read.csv("reproductive_modes_inland.csv", header = TRUE, row.names = 1,
                             sep = ",")
head(atribute_inland)

## Putting names of species in the same sequence
atribute_inland <- atribute_inland[match(colnames(inland_data), rownames(atribute_inland)),]
head(atribute_inland)

## Dissimilarity
atribute_dist_inland <- as.matrix(dist.binary(atribute_inland, method = 2, upper = T, diag = T))

comdist.result_inland_Func <- comdist(inland_data, atribute_dist_inland)
comdistnt.result_inland_Func <- comdistnt(inland_data, atribute_dist_inland)

## SES
ses_comdist_inland_Func <- ses.comdist(inland_data, atribute_dist_inland,
                                        null.model = "independentswap", runs = 999)
ses_comdistnt_inland_Func <- ses.comdistnt(inland_data, atribute_dist_inland,
                                            null.model = "independentswap", runs = 999)

################################ TAXONOMIC BETA #################################################
#################################################################################################

## Taxonomic beta- sites from both regions
##**********************************************************************************************

# calculating jaccard and 999 randomized values
obs.null <- data.frame(as.numeric(vegdist(my_data, "jaccard")),
                          replicate(999, as.numeric(vegdist(randomizeMatrix(my_data, 
                                                          null.model = "independentswap"),
                                                           index.family = "jaccard"))))

## SES
ses.all <- (obs.null[,1] - apply(obs.null[,-1] , 1, mean)) / apply(obs.null[,-1], 1, sd)


## Taxonomic beta - only Coastal sites
##*****************************************************************************

# calculating jaccard and 999 randomized values
obs.null_coastal <- data.frame(as.numeric(vegdist(coastal_data, "jaccard")),
                       replicate(999, as.numeric(vegdist(randomizeMatrix(coastal_data, 
                                                                         null.model = "independentswap"),
                                                         index.family = "jaccard"))))

## SES
ses.all_coastal <- (obs.null_coastal[,1] - apply(obs.null_coastal[,-1] , 1, mean)) / apply(obs.null_coastal[,-1], 1, sd)

## Taxonomic beta - only Inland sites
##*****************************************************************************

# calculating jaccard and 999 randomized values
obs.null_inland <- data.frame(as.numeric(vegdist(inland_data, "jaccard")),
                               replicate(999, as.numeric(vegdist(randomizeMatrix(inland_data, 
                                                                                 null.model = "independentswap"),
                                                                 index.family = "jaccard"))))

## SES
ses.all_inland <- (obs.null_inland[,1] - apply(obs.null_inland[,-1] , 1, mean)) / apply(obs.null_inland[,-1], 1, sd)